<?php

namespace SM\Factory;

use Doctrine\ORM\EntityManager;
use SM\Traits\TQuery;

class ModeloDocumentoCdaFactory
{

    use TQuery;

    protected $connection;

    protected $entityManager;

    public function __construct(EntityManager $entityManager)
    {
        $this->connection = $entityManager->getConnection();
        $this->entityManager = $entityManager;
    }

    public function getInformacoesModeloDocumentoCda()
    {
        $sql = "SELECT NRMODELODOCCDA,
                        DSMODELODOCORCA,
                        IDATIVO,
                        IDDOCPADRAO,
                        NRORG
                    FROM MODELODOCCDA
                    ORDER BY NRMODELODOCCDA DESC";
        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function getTabAnexoCda($params)
    {
        $sql = "SELECT
                    MO.NRMODELODOCCDAIDI,
                    MO.NRMODELODOCCDA,
                    MO.CDIDIOM,
                    MO.NMARQUIVO,
                    MO.DSCAMINHOARQ,
                    MO.DSTIPO,
                    MO.VRTAMANHO,
                    MO.IDATIVO,
                    IDI.NMIDIOMA,
                    IDI.IDPADRAO,
                    MO.NRORG
                FROM
                        MODELODOCCDAIDI MO
                    INNER JOIN IDIOMA IDI ON MO.CDIDIOM = IDI.CDIDIOM
                WHERE
                    MO.NRMODELODOCCDA = :NRMODELODOCCDA";
        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $params);
    }

    public function getModeloDocumentoPadraoCda($params)
    {
        $sql = "SELECT
                    MO.NRMODELODOCCDAIDI,
                    MO.NRMODELODOCCDA,
                    MO.CDIDIOM,
                    MD.IDDOCPADRAO,
                    IDI.NMIDIOMA,
                    IDI.IDPADRAO,
                    MO.NRORG
                FROM
                    MODELODOCCDAIDI MO,
                    MODELODOCCDA    MD,
                    IDIOMA          IDI
                WHERE
                        MO.CDIDIOM = :CDIDIOM
                    AND MO.NRMODELODOCCDA = MD.NRMODELODOCCDA
                    AND MO.CDIDIOM = IDI.CDIDIOM
                    AND MD.IDDOCPADRAO = 'S'";
        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $params);
    }

    public function inserirModeloDocumentoCda($parametros)
    {
        $sql = "INSERT INTO MODELODOCCDA (NRMODELODOCCDA, DSMODELODOCORCA, IDATIVO, IDDOCPADRAO, NRORG, NRORGINCLUSAO, CDOPERINCLUSAO, DTINCLUSAO)
        VALUES (:NRMODELODOCCDA, :DSMODELODOCORCA, :IDATIVO, :IDDOCPADRAO, :NRORG, :NRORGINCLUSAO, :CDOPERINCLUSAO, SYSDATE)";
        $this->connection->executeStatement($sql, $parametros);
    }

    public function saveTabModeloDocumentoCda($parametros)
    {
        $sql = "UPDATE MODELODOCCDA
                SET DSMODELODOCORCA       = :DSMODELODOCORCA,
                        IDATIVO           = :IDATIVO,
                        IDDOCPADRAO = :IDDOCPADRAO,
                        NRORGULTATU       = :NRORGULTATU,
                        CDOPERULTATU      = :CDOPERULTATU,
                        DTULTATU          = SYSDATE
                WHERE NRMODELODOCCDA = :NRMODELODOCCDA";
        $this->connection->executeStatement($sql, $parametros);
    }

    public function validaDocIdioma($params)
    {

        $sql = "SELECT COUNT (*) AS QTD 
                FROM MODELODOCCDAIDI
                WHERE NRMODELODOCCDA  = :NRMODELODOCCDA
                AND CDIDIOM           = :CDIDIOM
                AND NRMODELODOCCDAIDI <> NVL(:NRMODELODOCCDAIDI, -1)";

        return $this->connection->executeQuery($sql, $params)->fetchAllAssociative();
    }

    public function validaDoc($params)
    {

        $sql = "SELECT COUNT (*) AS QTD 
                    FROM MODELODOCCDAIDI
                    WHERE NRMODELODOCCDA  = :NRMODELODOCCDA
                    AND NMARQUIVO   = :NMARQUIVO
                    AND NMARQUIVO <> NVL(:NMARQUIVO, -1)";

        return $this->connection->executeQuery($sql, $params)->fetchAllAssociative();
    }

    public function inserirModeloDocumentoIdiomaCda($parametros)
    {
        $sql = "INSERT INTO MODELODOCCDAIDI (
                    NRMODELODOCCDAIDI,      NRMODELODOCCDA,         CDIDIOM,
                    IDATIVO,                NMARQUIVO,              DSCAMINHOARQ,           
                    DSTIPO,                 VRTAMANHO,              NRORG,                  
                    NRORGINCLUSAO,          CDOPERINCLUSAO,         DTINCLUSAO           
                    )
                    VALUES(
                    :NRMODELODOCCDAIDI,     :NRMODELODOCCDA,        :CDIDIOM,
                    :IDATIVO,               :NMARQUIVO,             :DSCAMINHOARQ,          
                    :DSTIPO,                :VRTAMANHO,             :NRORG,                 
                    :NRORGINCLUSAO,         :CDOPERINCLUSAO,        SYSDATE
                    )";
        $this->connection->executeStatement($sql, $parametros);
    }

    public function atualizarModeloDocumentoIdiomaCda($parametros)
    {
        $sql = "UPDATE MODELODOCCDAIDI
                SET NRMODELODOCCDA = :NRMODELODOCCDA,
                        CDIDIOM     = :CDIDIOM,
                        IDATIVO = :IDATIVO,
                        NMARQUIVO = :NMARQUIVO,
                        DSCAMINHOARQ = :DSCAMINHOARQ,
                        DSTIPO = :DSTIPO,
                        VRTAMANHO = :VRTAMANHO,
                        CDOPERULTATU = :CDOPERULTATU,
                        NRORGULTATU = :NRORGULTATU,
                        DTULTATU = SYSDATE
                WHERE NRMODELODOCCDAIDI = :NRMODELODOCCDAIDI";
        $this->connection->executeStatement($sql, $parametros);
    }

    public function atualizarModeloDocumentoCda($parametros)
    {
        $sql = "UPDATE MODELODOCCDA
                SET     CDOPERULTATU = :CDOPERULTATU,
                        NRORGULTATU = :NRORGULTATU,
                        DTULTATU = SYSDATE
                WHERE NRMODELODOCCDA = :NRMODELODOCCDA";
        $this->connection->executeStatement($sql, $parametros);
    }

    public function atualizarModeloDocumentoPadrao($parametros)
    {
        $sql = "UPDATE MODELODOCCDA
                   SET IDDOCPADRAO = :IDDOCPADRAO
                 WHERE NRMODELODOCCDA  <> :NRMODELODOCCDA";

        $this->connection->executeStatement($sql, $parametros);
    }

    public function deletarAnexoCda($params)
    {
        $sql = "DELETE FROM MODELODOCCDAIDI
                WHERE NRMODELODOCCDAIDI = :NRMODELODOCCDAIDI";
        $this->connection->executeStatement($sql, $params);
    }

    public function deletarModeloDocumentoCda($parametro)
    {
        $sql = "DELETE FROM MODELODOCCDA
                WHERE NRMODELODOCCDA = :NRMODELODOCCDA";
        $this->connection->executeStatement($sql, $parametro);
    }

    public function limparAnexoModeloDocumentoCda(array $params)
    {
        $sql = "UPDATE MODELODOCCDAIDI
                   SET DSCAMINHOARQ = NULL,
                       NMARQUIVO    = NULL,
                       VRTAMANHO    = NULL,
                       DSTIPO       = NULL
                 WHERE NRMODELODOCCDAIDI = :NRMODELODOCCDAIDI";
        $this->connection->executeStatement($sql, $params);
    }

    public function getDocumentoCda(array $params)
    {
        $sql = "SELECT NMARQUIVO,
                  VRTAMANHO,
                  DSCAMINHOARQ,
                  DSTIPO
                FROM MODELODOCCDAIDI
                WHERE NRMODELODOCCDAIDI = :NRMODELODOCCDAIDI";
        return $this->connection->executeQuery($sql, $params)->fetchAllAssociative();
    }
}
